@@ -59,3 +59,6 @@ options = {
     "TRACK_RESOLUTION": .5,
     "RESULT_MATCHING_MAX_DISTANCE": 5
 }
+
+# Used colors
+colors = []
