@@ -55,6 +55,9 @@ class OSM:
         """
 
         # Sanity check for bbox argument
+        if not bbox:
+            raise ValueError("No Bounding Box given!")
+
         if (type(bbox[0]) == float) or (type(bbox[0]) == np.float64):
             self._check_bbox(bbox)
             self.bbox = [bbox]
